@@ -237,7 +237,7 @@ def download_objects_inner(endpoint, bucketname, parentdir, array_of_files, is_c
     pipe_from_child = []
     processes = []
     for i in range(num_threads()):
-        r1, w1 = Pipe()
+        r1, w1 = Pipe(False)
         pipe_from_child.append(r1)
         p = Process(target=s3downloader, args=(command_q, w1, endpoint, glb,))
         p.start()
@@ -249,20 +249,27 @@ def download_objects_inner(endpoint, bucketname, parentdir, array_of_files, is_c
     step = 0
     with tqdm(total=len(array_of_files)) as pbar:
         files_read = 0
-        while (len(pipe_from_child) > 0):
-            for read_pipe in wait(pipe_from_child):
-                try:
-                    key = read_pipe.recv()
-                    bts = read_pipe.recv()
-                    filekeys.append(key)
-                    filebytes.append(bts)
-                    pbar.update(1)
-                    files_read += 1
-                    if ((files_read % 10) == 0):
-                        log_metric("downloaded", files_read, step=step)
-                        step += 1
-                except EOFError:
-                    pipe_from_child.remove(read_pipe)
+        while pipe_from_child:
+            ready = wait(pipe_from_child, timeout=2)
+            if (ready == None):
+                info('>>>>>>>>>>>>>> received None from wait >>>>>>>>>>>>')
+            else:
+                if (len(ready) == 0):
+                    info('>>>>>>>>>>>>>> WARNING: None ready from wait >>>>>>>>>>>>')
+                for read_pipe in ready:
+                    try:
+                        key = read_pipe.recv()
+                        bts = read_pipe.recv()
+                        filekeys.append(key)
+                        filebytes.append(bts)
+                        pbar.update(1)
+                        files_read += 1
+                        if ((files_read % 10) == 0):
+                            log_metric("downloaded", files_read, step=step)
+                            info("Downloaded " + str(files_read))
+                            step += 1
+                    except EOFError:
+                        pipe_from_child.remove(read_pipe)
 
     for i in range(num_threads()):
         processes[i].join()
